@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
@@ -51,6 +51,7 @@ typedef struct
 {
 	TotemPlugin   parent;
 	TotemObject  *totem;
+	BaconVideoWidget *bvw;
 
 	TotemScrsaver *scr;
 	guint          handler_id_playing;
@@ -66,7 +67,6 @@ typedef struct
 G_MODULE_EXPORT GType register_totem_plugin		(GTypeModule *module);
 GType	totem_screensaver_plugin_get_type		(void) G_GNUC_CONST;
 
-static void totem_screensaver_plugin_init		(TotemScreensaverPlugin *plugin);
 static void totem_screensaver_plugin_finalize		(GObject *object);
 static gboolean impl_activate				(TotemPlugin *plugin, TotemObject *totem, GError **error);
 static void impl_deactivate				(TotemPlugin *plugin, TotemObject *totem);
@@ -136,6 +136,12 @@ property_notify_cb (TotemObject *totem,
 	totem_screensaver_update_from_state (totem, pi);
 }
 
+static void
+got_metadata_cb (BaconVideoWidget *bvw, TotemScreensaverPlugin *pi)
+{
+	totem_screensaver_update_from_state (pi->totem, pi);
+}
+
 static void
 lock_screensaver_on_audio_changed_cb (GConfClient *client, guint cnxn_id,
 				      GConfEntry *entry, TotemScreensaverPlugin *pi)
@@ -151,6 +157,8 @@ impl_activate (TotemPlugin *plugin,
 	TotemScreensaverPlugin *pi = TOTEM_SCREENSAVER_PLUGIN (plugin);
 	GConfClient *gc;
 
+	pi->bvw = BACON_VIDEO_WIDGET (totem_get_video_widget (totem));
+
 	gc = gconf_client_get_default ();
 	gconf_client_add_dir (gc, GCONF_PREFIX,
 			      GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
@@ -163,6 +171,10 @@ impl_activate (TotemPlugin *plugin,
 				"notify::playing",
 				G_CALLBACK (property_notify_cb),
 				pi);
+	pi->handler_id_playing = g_signal_connect (G_OBJECT (pi->bvw),
+				"got-metadata",
+				G_CALLBACK (got_metadata_cb),
+				pi);
 
 	pi->totem = g_object_ref (totem);
 
@@ -186,6 +198,7 @@ impl_deactivate	(TotemPlugin *plugin,
 	g_signal_handler_disconnect (G_OBJECT (totem), pi->handler_id_playing);
 
 	g_object_unref (pi->totem);
+	g_object_unref (pi->bvw);
 
 	totem_scrsaver_enable (pi->scr);
 }
