@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
@@ -49,7 +49,6 @@ struct TotemSkiptoPluginPrivate
 
 G_MODULE_EXPORT GType register_totem_plugin		(GTypeModule *module);
 
-static void totem_skipto_plugin_init			(TotemSkiptoPlugin *plugin);
 static void totem_skipto_plugin_finalize		(GObject *object);
 static gboolean impl_activate				(TotemPlugin *plugin, TotemObject *totem, GError **error);
 static void impl_deactivate				(TotemPlugin *plugin, TotemObject *totem);
@@ -219,7 +218,7 @@ impl_activate (TotemPlugin *plugin,
 	builder_path = totem_plugin_find_file (TOTEM_PLUGIN (plugin), "skipto.ui");
 	if (builder_path == NULL) {
 		g_set_error (error, TOTEM_PLUGIN_ERROR, TOTEM_PLUGIN_ERROR_ACTIVATION,
-				_("Could not load the \"Skip to\" dialogue interface."));
+				_("Could not load the \"Skip to\" dialog interface."));
 		return FALSE;
 	}
 	g_free (builder_path);
