@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with the Gnome Library; see the file COPYING.LIB.  If not,
- *  write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301  USA.
  *
  *  Author: Bastien Nocera <hadess@hadess.net>
  * 
@@ -35,8 +35,10 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
+#include <gconf/gconf-client.h>
 
 #include "totem-interface.h"
+#include "totem-private.h"
 
 static GtkWidget *
 totem_interface_error_dialog (const char *title, const char *reason,
@@ -75,13 +77,10 @@ totem_interface_error (const char *title, const char *reason,
 
 	error_dialog = totem_interface_error_dialog (title, reason, parent);
 
-	g_signal_connect (G_OBJECT (error_dialog), "destroy", G_CALLBACK
-			(gtk_widget_destroy), error_dialog);
 	g_signal_connect (G_OBJECT (error_dialog), "response", G_CALLBACK
 			(gtk_widget_destroy), error_dialog);
-	gtk_window_set_modal (GTK_WINDOW (error_dialog), TRUE);
 
-	gtk_widget_show (error_dialog);
+	gtk_window_present (GTK_WINDOW (error_dialog));
 }
 
 void
@@ -96,6 +95,65 @@ totem_interface_error_blocking (const char *title, const char *reason,
 	gtk_widget_destroy (error_dialog);
 }
 
+static void
+link_button_clicked_cb (GtkWidget *widget, Totem *totem)
+{
+	const char *uri;
+	char *command, *browser, *escaped_uri;
+	GError *error = NULL;
+
+	uri = gtk_link_button_get_uri (GTK_LINK_BUTTON (widget));
+	escaped_uri = g_shell_quote (uri);
+	browser = gconf_client_get_string (totem->gc, "/desktop/gnome/url-handlers/http/command", NULL);
+
+	if (browser == NULL || browser[0] == '\0') {
+		char *message;
+
+		message = g_strdup_printf(_("Could not launch URL \"%s\": %s"), uri, _("Default browser not configured"));
+		totem_interface_error (_("Error launching URI"), message, GTK_WINDOW (totem->win));
+		g_free (message);
+	} else {
+		char *message;
+
+		command = g_strdup_printf (browser, escaped_uri);
+		if (g_spawn_command_line_async ((const char*) command, &error) == FALSE) {
+			message = g_strdup_printf(_("Could not launch URL \"%s\": %s"), uri, error->message);
+			totem_interface_error (_("Error launching URI"), message, GTK_WINDOW (totem->win));
+			g_free (message);
+			g_error_free (error);
+		}
+		g_free (command);
+	}
+
+	g_free (escaped_uri);
+	g_free (browser);
+}
+
+void
+totem_interface_error_with_link (const char *title, const char *reason,
+				 const char *uri, const char *label, GtkWindow *parent, Totem *totem)
+{
+	GtkWidget *error_dialog, *link_button, *hbox;
+
+	if (label == NULL)
+		label = uri;
+
+	error_dialog = totem_interface_error_dialog (title, reason, parent);
+	link_button = gtk_link_button_new_with_label (uri, label);
+	g_signal_connect (G_OBJECT (link_button), "clicked", G_CALLBACK (link_button_clicked_cb), totem);
+
+	hbox = gtk_hbox_new (TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), link_button, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (error_dialog)->vbox), hbox, TRUE, FALSE, 0); 
+
+	gtk_dialog_set_default_response (GTK_DIALOG (error_dialog), GTK_RESPONSE_OK);
+
+	g_signal_connect (G_OBJECT (error_dialog), "response", G_CALLBACK
+			(gtk_widget_destroy), error_dialog);
+
+	gtk_window_present (GTK_WINDOW (error_dialog));
+}
+
 GtkBuilder *
 totem_interface_load (const char *name, gboolean fatal, GtkWindow *parent, gpointer user_data)
 {
@@ -103,6 +161,19 @@ totem_interface_load (const char *name, gboolean fatal, GtkWindow *parent, gpoin
 	char *filename;
 
 	filename = totem_interface_get_full_path (name);
+	if (filename == NULL) {
+		char *msg;
+
+		msg = g_strdup_printf (_("Couldn't load the '%s' interface. %s"), name, _("The file does not exist."));
+		if (fatal == FALSE)
+			totem_interface_error (msg, _("Make sure that Totem is properly installed."), parent);
+		else
+			totem_interface_error_blocking (msg, _("Make sure that Totem is properly installed."), parent);
+
+		g_free (msg);
+		return NULL;
+	}
+
 	builder = totem_interface_load_with_full_path (filename, fatal, parent,
 						       user_data);
 	g_free (filename);
@@ -122,8 +193,7 @@ totem_interface_load_with_full_path (const char *filename, gboolean fatal,
 		gtk_builder_set_translation_domain (builder, GETTEXT_PACKAGE);
 	}
 
-	if (builder == NULL || gtk_builder_add_from_file (builder, filename, &error) == FALSE)
-	{
+	if (builder == NULL || gtk_builder_add_from_file (builder, filename, &error) == FALSE) {
 		char *msg;
 
 		msg = g_strdup_printf (_("Couldn't load the '%s' interface. %s"), filename, error->message);
@@ -267,6 +337,7 @@ void
 totem_interface_boldify_label (GtkBuilder *builder, const char *name)
 {
 	GtkLabel *widget;
+	gchar *str_final;
 
 	widget = GTK_LABEL (gtk_builder_get_object (builder, name));
 
@@ -291,7 +362,6 @@ totem_interface_boldify_label (GtkBuilder *builder, const char *name)
 	}
 	gtk_label_set_attributes (widget, pattrlist);*/
 
-	gchar *str_final;
 	str_final = g_strdup_printf ("<b>%s</b>", gtk_label_get_label (widget));
 	gtk_label_set_markup_with_mnemonic (widget, str_final);
 	g_free (str_final);
@@ -301,6 +371,7 @@ void
 totem_interface_italicise_label (GtkBuilder *builder, const char *name)
 {
 	GtkLabel *widget;
+	gchar *str_final;
 
 	widget = GTK_LABEL (gtk_builder_get_object (builder, name));
 
@@ -325,7 +396,6 @@ totem_interface_italicise_label (GtkBuilder *builder, const char *name)
 	}
 	gtk_label_set_attributes (widget, pattrlist);*/
 
-	gchar *str_final;
 	str_final = g_strdup_printf ("<i>%s</i>", gtk_label_get_label (widget));
 	gtk_label_set_markup_with_mnemonic (widget, str_final);
 	g_free (str_final);
